Index: trunk/ppSim/src/ppSimInsertStars.c
===================================================================
--- trunk/ppSim/src/ppSimInsertStars.c	(revision 20367)
+++ trunk/ppSim/src/ppSimInsertStars.c	(revision 21365)
@@ -39,7 +39,7 @@
     float skyRate = psMetadataLookupF32(NULL, recipe, "SKY.RATE"); // Sky rate
     if (isnan(skyRate)) {
-	float zp      = psMetadataLookupF32(&mdok, recipe, "ZEROPOINT"); assert (mdok);
-	float scale   = psMetadataLookupF32(&mdok, recipe, "PIXEL.SCALE");     assert (mdok);
-	float skyMags = psMetadataLookupF32(&mdok, recipe, "SKY.MAGS");  assert (mdok);
+        float zp      = psMetadataLookupF32(&mdok, recipe, "ZEROPOINT"); assert (mdok);
+        float scale   = psMetadataLookupF32(&mdok, recipe, "PIXEL.SCALE");     assert (mdok);
+        float skyMags = psMetadataLookupF32(&mdok, recipe, "SKY.MAGS");  assert (mdok);
         skyRate = scale * scale * ppSimMagToFlux (skyMags, zp);
     }
@@ -75,5 +75,5 @@
     FILE *outfile = fopen (outname, "w");
 
     // add sources to the readout image & weight
     psTrace("ppSim", 1, "Inserting %ld stars...\n", stars->n);
     for (long i = 0; i < stars->n; i++) {
@@ -118,5 +118,5 @@
         psF64 Area = 2.0 * M_PI * axes.major * axes.minor;
 
-	// this value is the pure (input) flux, and is saved in the output source cmf files
+        // this value is the pure (input) flux, and is saved in the output source cmf files
         source->psfMag = -2.5*log10(star->flux);
         source->errMag = sqrt(Area*PS_SQR(roughNoise) + flux) / flux;
@@ -132,5 +132,5 @@
         // Blow away the image parts of the source, which makes the memory explode
         RESET(source->pixels);
-        RESET(source->weight);
+        RESET(source->variance);
         RESET(source->maskObj);
         RESET(source->maskView);
@@ -75,5 +75,5 @@
     FILE *outfile = fopen (outname, "w");
 
-    // add sources to the readout image & weight
+    // add sources to the readout image & variance
     psTrace("ppSim", 1, "Inserting %ld stars...\n", stars->n);
     for (long i = 0; i < stars->n; i++) {
